@@ -50,7 +50,7 @@ class LoginRequest(DSRequest):
                     # if len(visitors_all) > 1:
                     #     Visitor.objects.using('history').filter(username=login).delete()
 
-                    if settings.FREQUENCY_OF_POLLING_UNREAD_MESSAGES == None:
+                    if settings.FREQUENCY_OF_POLLING_UNREAD_MESSAGES is None:
                         settings.FREQUENCY_OF_POLLING_UNREAD_MESSAGES = 1000 * 60 * 3
 
                     visitors = [visitor.ip_address for visitor in Visitor.objects.using('history').filter(username=login).exclude(ip_address=ip)]
@@ -79,7 +79,7 @@ class LoginRequest(DSRequest):
                         else:
                             workshops = [Locations_view.objects.get(id=Locations_users.location.id).workshop for Locations_users in Locations_users.objects.filter(user=user)]
                             workshops = [workshop.id if workshop else 0 for workshop in workshops]
-                            if len(workshops) == None:
+                            if len(workshops) == 0:
                                 workshops = [-1]
 
                         self.response = dict(
@@ -105,7 +105,7 @@ class LoginRequest(DSRequest):
                             Operations_Plan=settings.OPERATIONS_PLAN.OPERSTYPES,
                             # progresses=[ProgressesManager.getRecord(item) for item in Progresses.objects.filter(user=user)],
                             status=RPCResponseConstant.statusSuccess,
-                            user__color=user.color if user.color != None and user.color != 'undefined' else 'black',
+                            user__color=user.color if user.color is not None and user.color != 'undefined' else 'black',
                             user_full_name=user.get_full_name,
                             user_short_name=user.get_short_name,
                             workshops=workshops,
